@@ -320,6 +320,12 @@ tbl_vars.tbl_kusto_abstract <- function(x)
     op_vars(x$ops)
 }
 
+#' @export
+group_vars.tbl_kusto_abstract <- function(x)
+{
+    op_grps(x$ops)
+}
+
 #' Translate a sequence of dplyr operations on a tbl into a Kusto query string.
 #' @export
 #' @param tbl A tbl_kusto or tbl_kusto_abstract instance
@@ -349,7 +355,7 @@ tbl_kusto <- function(kusto_database, table_name, ...)
     make_tbl(c("kusto", "kusto_abstract"), src = kusto_database, ops = ops, params = params)
 }
 
-#' Compile the preceding dplyr oprations into a kusto query, execute it on the remote server,
+#' Compile the preceding dplyr operations into a kusto query, execute it on the remote server,
 #' and return the result as a tibble.
 #' @export
 #' @param tbl An instance of class tbl_kusto representing a Kusto table
